@@ -3,12 +3,16 @@ from fastai  import *
 from fastai.vision import *
 import sys
 import os
-
+import imp
 warnings.filterwarnings("ignore")
 
+
+
 def Determine(path):
-    path=os.path.dirname(os.path.abspath(__file__))
-    learn=load_learner(r'{}'.format(path))
+    prefix=sys.prefix
+    
+    
+    learn=load_learner(imp.find_module('detect_mask')[1])
     img=open_image(path)
     k=learn.predict(img)[1]
     if k==1:
@@ -16,6 +20,3 @@ def Determine(path):
     else:
         return (1,'Mask')
     
-    
-
-
